import auth from '../../lib/Authority';

describe ('authority', () => {
  beforeEach (() => {
    jasmine.clock ()
      .install ();
    jasmine.clock ()
      .mockDate (new Date);
  });

  afterEach (() => {
    jasmine.clock ()
      .uninstall ();
  });

  it ('should create an access token', () => {
    const token = auth.sign ('access_token', 60);
    jasmine.clock ()
      .tick (30000);
    const res = auth.verify (token.signature);
    expect (res.authorized)
      .toBeTrue ();
    expect (res.type)
      .toEqual ('access_token');
    expect (res.next_module)
      .toBeUndefined ();
  });

  it ('should create a refresh token', () => {
    const token = auth.sign ('refresh_token', 600);
    jasmine.clock ()
      .tick (30000);
    const res = auth.verify (token.signature);
    expect (res.authorized)
      .toBeFalse ();
    expect (res.type)
      .toEqual ('refresh_token');
    expect (res.next_module)
      .toBeUndefined ();
  });

  it ('should create a part token', () => {
    const token = auth.sign ('part_token', 60, '2fa');
    jasmine.clock ()
      .tick (30000);
    const res = auth.verify (token.signature);
    expect (res.authorized)
      .toBeFalse ();
    expect (res.type)
      .toEqual ('part_token');
    expect (res.next_module)
      .toEqual ('2fa');
  });
});
